@@ -4,8 +4,8 @@ package Dist::Zilla::Plugin::Git::Contributors;
 BEGIN {
   $Dist::Zilla::Plugin::Git::Contributors::AUTHORITY = 'cpan:ETHER';
 }
-# git description: v0.002-3-gb8f41f1
-$Dist::Zilla::Plugin::Git::Contributors::VERSION = '0.003';
+# git description: v0.003-9-gfd0c9cc
+$Dist::Zilla::Plugin::Git::Contributors::VERSION = '0.004';
 # ABSTRACT: Add contributor names from git to your distribution
 # KEYWORDS: plugin distribution metadata git contributors authors commits
 # vim: set ts=8 sw=4 tw=78 et :
@@ -18,6 +18,8 @@ use Git::Wrapper;
 use Try::Tiny;
 use Safe::Isa;
 use Path::Tiny;
+use Data::Dumper;
+use Moose::Util::TypeConstraints 'enum';
 use namespace::autoclean;
 
 has include_authors => (
@@ -30,6 +32,11 @@ has include_releaser => (
     default => 1,
 );
 
+has order_by => (
+    is => 'ro', isa => enum([qw(name commits)]),
+    default => 'name',
+);
+
 around dump_config => sub
 {
     my ($orig, $self) = @_;
@@ -38,6 +45,7 @@ around dump_config => sub
     $config->{+__PACKAGE__} = {
         include_authors => $self->include_authors,
         include_releaser  => $self->include_releaser,
+        order_by => $self->order_by,
     };
 
     return $config;
@@ -54,24 +62,14 @@ sub metadata
     +{ x_contributors => $contributors };
 }
 
-has _git => (
-    is => 'ro',
-    isa => 'Git::Wrapper',
-    lazy => 1,
-    default => sub { Git::Wrapper->new(path('.')->absolute->stringify) },
-);
-
 sub _contributors
 {
     my $self = shift;
 
-    my $git = $self->_git;
-
     # figure out if we're in a git repo or not
     my $in_repo;
     try {
-        $in_repo = $git->RUN('status');
-        my $err = $git->ERR; $self->log(@$err) if @$err;
+        $in_repo = $self->_git(RUN => 'status');
     }
     catch {
         $self->log($_->error) if $_->$_isa('Git::Wrapper::Exception');
@@ -79,11 +77,14 @@ sub _contributors
 
     return [] if not $in_repo;
 
-    my @data = $git->shortlog('HEAD', { email => 1, summary => 1});
-    my $err = $git->ERR; $self->log(@$err) if @$err;
+    my @data = $self->_git(shortlog => 'HEAD',
+        { email => 1, summary => 1, ($self->order_by eq 'commits' ? (numbered => 1) : ()) });
 
     my @contributors = map { utf8::decode($_); m/^\s*\d+\s*(.*)$/g; } @data;
 
+    $self->log_debug([ 'extracted contributors from git: %s',
+        sub { Data::Dumper->new([ \@contributors ])->Indent(2)->Terse(1)->Dump } ]);
+
     if (not $self->include_authors)
     {
         my $authors = $self->zilla->authors;
@@ -106,13 +107,8 @@ sub _releaser
 {
     my $self = shift;
 
-    my $git = $self->_git;
-
-    my ($username) = $git->config('user.name');
-    my $err = $git->ERR; $self->log(@$err) if @$err;
-
-    my ($email) = $git->config('user.email');
-    $err = $git->ERR; $self->log(@$err) if @$err;
+    my ($username) = $self->_git(config => 'user.name');
+    my ($email) = $self->_git(config => 'user.email');
 
     return if not $username or not $email;
     $username . ' <' . $email . '>';
@@ -128,6 +124,23 @@ sub _check_podweaver
             and not eval { Pod::Weaver::Section::Contributors->VERSION(0.007001); 1 };
 }
 
+has __git => (
+    is => 'ro',
+    isa => 'Git::Wrapper',
+    lazy => 1,
+    default => sub { Git::Wrapper->new(path('.')->absolute->stringify) },
+);
+
+sub _git
+{
+    my ($self, $command, @args) = @_;
+
+    my $git = $self->__git;
+    my @result = $git->$command(@args);
+    my $err = $git->ERR; $self->log(@$err) if @$err;
+    return @result;
+}
+
 __PACKAGE__->meta->make_immutable;
 
 __END__
@@ -142,7 +155,7 @@ Dist::Zilla::Plugin::Git::Contributors - Add contributor names from git to your
 
 =head1 VERSION
 
-version 0.003
+version 0.004
 
 =head1 SYNOPSIS
 
@@ -163,26 +176,27 @@ distribution metadata.
 
 =head2 C<include_authors>
 
-By default, distribution authors are removed from the list of extracted git
-contributors. To disable this, set C<include_authors = 1>.
+When true, authors are added to the list of contributors. When false, authors
+are filtered out of the list of contributors.  Defaults to false.
 
 =head2 C<include_releaser>
 
+This option is B<EXPERIMENTAL> and may be removed!
+
 Defaults to true; set to false to remove the current user (who is doing the
 distribution release) from the contributors list. It is applied after
 C<include_authors>, so you will be removed from the list even if you are (one
 of the) distribution author(s) and C<include_authors = 1>.
 
-=for stopwords metacpan
+=head2 C<order_by>
 
-For most distributions, C<< include_authors = 1, include_releaser = 0 >> seems
-to be the right combination of configs to use, particularly for how
-distributions are displayed on L<metacpan|http://metacpan.org>. Perhaps these
-should be the defaults?
+When C<order_by = name>, contributors are sorted alphabetically
+(ascending); when C<order_by = commits>, contributors are sorted by number of
+commits made to the repository (descending). Th default value is C<name>.
 
 =for stopwords canonicalizing
 
-=head2 CANONICALIZING NAMES AND ADDRESSES
+=head1 CANONICALIZING NAMES AND ADDRESSES
 
 If you or a contributor uses multiple names and/or email addresses to make
 commits and would like them mapped to a canonical value, you can do this by
@@ -190,11 +204,20 @@ adding a F<.mailmap> file to your git repository, with entries formatted as
 described in "MAPPING AUTHORS" in C<git help shortlog>
 (L<https://www.kernel.org/pub/software/scm/git/docs/git-shortlog.html>).
 
-=head2 ADDING CONTRIBUTORS TO POD DOCUMENTATION
+=head1 ADDING CONTRIBUTORS TO POD DOCUMENTATION
 
 You can add the contributor names to your module documentation by using
 L<Pod::Weaver> in conjunction with L<Pod::Weaver::Section::Contributors>.
 
+=head1 UNICODE SUPPORT
+
+=for stopwords ascii
+
+This module aims to properly handle non-ascii characters in contributor names.
+However, on Windows you might need to do a bit more: see
+L<https://github.com/msysgit/msysgit/wiki/Git-for-Windows-Unicode-Support> for
+supported versions and extra configurations you may need to apply.
+
 =head1 SUPPORT
 
 =for stopwords irc
