@@ -5,6 +5,7 @@ package GitSetup;
 use Test::More;
 use Git::Wrapper;
 use Sort::Versions;
+use Config;
 
 use parent 'Exporter';
 our @EXPORT = qw(git_wrapper);
@@ -24,12 +25,18 @@ sub git_wrapper
     diag 'Testing with git version: ', $version;
     plan skip_all => "Need git v1.5.0 for 'config' subcommand" if versioncmp($version, '1.5.0') < 0;
 
+    plan skip_all => 'Need mysysgit v1.7.10 for proper unicode support on windows (https://github.com/msysgit/msysgit/wiki/Git-for-Windows-Unicode-Support)'
+        if $Config{osname} eq 'MSWin32' and versioncmp($version, '1.7.10') < 0;
+
     $git->init;
     $err = $git->ERR; diag explain @$err if @$err;
 
     $git->config('user.name', 'Test User');
     $git->config('user.email', 'test@example.com');
 
+    $git->config('i18n.logoutputencoding', 'utf-8') if $Config{osname} eq 'MSWin32';
+    $git->config('i18n.commitencoding', 'utf-8') if $Config{osname} eq 'MSWin32';
+
     $git;
 }
 
